@@ -45,9 +45,11 @@ if [ "${DO_FULL}" == "0" ]; then
 	BUILD_OPTIONS="${BUILD_OPTIONS} --without-webcam"
 	BUILD_OPTIONS="${BUILD_OPTIONS} --without-win32_tools"
 	BUILD_OPTIONS="${BUILD_OPTIONS} --without-docs"
+	BUILD_OPTIONS="${BUILD_OPTIONS} --without-qt6_client"
 	BUILD_OPTIONS="${BUILD_OPTIONS} --with-Os"
 	shift
 else
+	BUILD_OPTIONS="${BUILD_OPTIONS} --with-qt6_client"
   BUILD_TYPE="Full"
 fi
 if [ "${DO_CUDA}" == "0" ]; then
@@ -282,7 +284,7 @@ if [ "${DO_SERVICE}" == "1" ]; then
 fi
 
 if [ "${DO_CUDA}" == "1" ]; then
-	echo "* Building all the CUDA kernels"
+	echo "* Building the CUDA kernels"
 	BUILD_CUDA_KERNEL="packaging\\MSWindows\\BUILD_CUDA_KERNEL"
 	for cupath in `ls fs/share/xpra/cuda/*.cu`; do
 		cu=`basename $cupath`
@@ -296,7 +298,7 @@ else
 	BUILD_OPTIONS="${BUILD_OPTIONS} --without-nvenc --without-nvjpeg_encoder --without-nvjpeg_decoder --without-nvfbc"
 fi
 
-echo "* Building Python3 Cython modules"
+echo "* Building Cython modules"
 BUILD_LOG="packaging/MSWindows/Python3-build.log"
 NPROCS=${NPROCS:-`nproc`}
 ${PYTHON} ./setup.py build_ext ${BUILD_OPTIONS} --inplace -j ${NPROCS} >& ${BUILD_LOG}
@@ -497,14 +499,14 @@ rmdir xpra/* 2> /dev/null
 if [ "${ZIP_MODULES}" == "1" ]; then
 	#these modules contain native code or data files,
 	#so they will require special treatment:
-	#xpra numpy cryptography PIL nacl cffi gtk gobject glib > /dev/null
+	#xpra numpy cryptography PIL nacl cffi gtk gobject glib aioquic pylsqpack > /dev/null
 	if [ "${DO_FULL}" == "0" ]; then
-		rm -fr test unittest gssapi pynvml ldap ldap3 pyasn1 asn1crypto pyu2f sqlite3 psutil
+		rm -fr test unittest gssapi pynvml ldap ldap3 pyu2f sqlite3 psutil
 	else
-		zip --move -ur library.zip test unittest gssapi pynvml ldap ldap3 pyasn1 asn1crypto pyu2f sqlite3 psutil
+		zip --move -ur library.zip test unittest gssapi pynvml ldap ldap3 pyu2f sqlite3 psutil
 	fi
 	zip --move -ur library.zip OpenGL encodings future paramiko html \
-			aioquic pylsqpack async_timeout \
+			pyasn1 asn1crypto async_timeout \
 			certifi OpenSSL pkcs11 keyring \
 			ifaddr pyaes browser_cookie3 service_identity\
 			re platformdirs attr setproctitle pyvda zipp \
@@ -536,6 +538,10 @@ for i in `seq 4`; do
 	find share/icons -type d -exec rmdir {} \; 2> /dev/null
 done
 
+if [ "${DO_FULL}" == "0" ]; then
+  rm qt.conf
+fi
+
 #leave ./dist
 popd > /dev/null
 
@@ -600,8 +606,8 @@ fi
 
 if [ "${BUNDLE_OPENSSL}" == "1" ]; then
 	cp -fn "${MINGW_PREFIX}/bin/openssl.exe" "${DIST}/"
-	#use the old filename so we don't have to change the xpra.iss and the setup.py build system:
-	cp -fn "${MINGW_PREFIX}/ssl/openssl.cnf" "${DIST}/openssl.cfg"
+	mkdir -p "${DIST}/etc/ssl"
+	cp -fn "${MINGW_PREFIX}/etc/ssl/openssl.cnf" "${DIST}/etc/ssl/openssl.cnf"
 	#we need those libraries at the top level:
 	mv "${DIST}"/lib/libssl-*dll "${DIST}/"
 	mv "${DIST}"/lib/libcrypto-*dll "${DIST}/"
