@@ -221,8 +221,13 @@ for x in `ls "$HELPERS_DIR" | egrep -v "Python|gst-plugin-scanner"`; do
 done
 #fix for:
 # dyld: Library not loaded: @executable_path/../Resources/lib/libgstreamer-1.0.0.dylib
+pushd $RSCDIR/libexec
+ln -sf ../../Resources ./Resources
+popd
+#fix for:
+# /Applications/Xpra.app/Contents/Resources/bin/../Resources/lib/gdk-pixbuf-2.0/2.10.0/loaders/libpixbufloader-svg.so
 pushd $RSCDIR
-ln -sf . Resources
+ln -sf ../Resources ./Resources
 popd
 
 # launcher needs to be in main ("MacOS" dir) since it is launched from the custom Info.plist:
@@ -358,6 +363,8 @@ if [ "$STRIP_GSTREAMER_PLUGINS" == "1" ]; then
 	KEEP="./gstreamer-1.0.keep"
 	mkdir ${KEEP}
 	PLUGINS="app audio coreelements cutter removesilence faac faad flac oss osxaudio speex volume vorbis wav lame opus ogg gdp isomp4 matroska videoconvert x264 vpx"
+	#video sink for testing:
+	PLUGINS="${PLUGINS} autodetect osxvideo"
 	#video support:
 	PLUGINS="${PLUGINS} vpx x264 aom openh264 videoconvert videorate videoscale libav"
 	for x in $PLUGINS; do
@@ -436,6 +443,17 @@ for x in `ls *dylib | grep -v libgst | sed 's+[0-9\.]*\.dylib++g' | sed 's+-$++g
 		done
 	fi
 done
+#gstreamer dylibs are easier
+#all of them look like this: libgstXYZ-1.0.0.dylib / libgstXYZ-1.0.dylib
+for x in `ls libgst*-1.0.0.dylib`; do
+  SHORT="`echo $x | sed 's/1.0.0/1.0/g'`"
+  cmp -s "$x" "$SHORT"
+  if [ "$?" == "0" ]; then
+		echo "(re)symlinking $SHORT to $x"
+		rm $SHORT
+		ln -sf $x $SHORT
+	fi
+done
 popd
 
 
